Resources
=========

ZTPServer documentation and other reference materials are below:

    * `GitHub ZTPServer Repository <https://github.com/arista-eosplus/ztpserver>`_
    * ZTPServer `wiki <https://github.com/arista-eosplus/ztpserver/wiki>`_
    * `Packer VM <https://github.com/arista-eosplus/ztpserver/tree/feature-packer/packer>`_ build process.
    * `ZTPServer <https://pypi.python.org/pypi/ztpserver>`_ Python (PyPI) package.
    * `YAML Code Validator <http://yamllint.com/>`_

